@@ -30,6 +30,9 @@ b = [6,7]
 #? int()
 b[8-7]
 
+# -----------------
+# Slices
+# -----------------
 #? list()
 b[8:]
 
@@ -37,6 +40,15 @@ b[8:]
 b[int():]
 
 
+class _StrangeSlice():
+    def __getitem__(self, slice):
+        return slice
+
+# Should not result in an error, just because the slice itself is returned.
+#? []
+_StrangeSlice()[1:2]
+
+
 # -----------------
 # iterable multiplication
 # -----------------
@@ -44,14 +56,6 @@ a = ['']*2
 #? list()
 a
 
-a = 2*2
-#? int()
-a
-
-a = "a"*3
-#? str()
-a
-
 # -----------------
 # tuple assignments
 # -----------------
@@ -220,7 +224,7 @@ f()
 d = dict({'a':''})
 def y(a):
     return a
-#? 
+#?
 y(**d)
 
 # problem with more complicated casts
@@ -272,6 +276,17 @@ class GetItem():
 #? str()
 GetItem("")[1]
 
+class GetItemWithList():
+    def __getitem__(self, index):
+        return [1, 1.0, 's'][index]
+
+#? float()
+GetItemWithList()[1]
+
+for i in 0, 2:
+    #? int() str()
+    GetItemWithList()[i]
+
 # -----------------
 # conversions
 # -----------------
@@ -282,7 +297,7 @@ list(a)[1]
 
 #? int() str()
 list(a)[0]
-#? 
+#?
 set(a)[0]
 
 #? int() str()
@@ -322,3 +337,31 @@ tuple((1,))[0]
 # implementation detail for lists, should not be visible
 #? []
 list().__iterable
+
+# With a list comprehension.
+for i in set(a for a in [1]):
+    #? int()
+    i
+
+
+# -----------------
+# Recursions
+# -----------------
+
+def to_list(iterable):
+    return list(set(iterable))
+
+
+def recursion1(foo):
+    return to_list(to_list(foo)) + recursion1(foo)
+
+#? int()
+recursion1([1,2])[0]
+
+# -----------------
+# Merged Arrays
+# -----------------
+
+for x in [1] + ['']:
+    #? int() str()
+    x
