@@ -1,10 +1,11 @@
 # -----------------
 # yield statement
 # -----------------
-
 def gen():
-    yield 1
-    yield ""
+    if random.choice([0, 1]):
+        yield 1
+    else:
+        yield ""
 
 gen_exe = gen()
 #? int() str()
@@ -13,6 +14,7 @@ next(gen_exe)
 #? int() str() list
 next(gen_exe, list)
 
+
 def gen_ret(value):
     yield value
 
@@ -22,12 +24,22 @@ next(gen_ret(1))
 #? []
 next(gen_ret())
 
+# generators evaluate to true if cast by bool.
+a = ''
+if gen_ret():
+    a = 3
+#? int()
+a
+
+
 # -----------------
 # generators should not be indexable
 # -----------------
 def get(param):
-    yield 1
-    yield ""
+    if random.choice([0, 1]):
+        yield 1
+    else:
+        yield ""
 
 #? []
 get()[0]
@@ -39,10 +51,13 @@ for a in get():
     #? int() str()
     a
 
+
 class Get():
     def __iter__(self):
-        yield 1
-        yield ""
+        if random.choice([0, 1]):
+            yield 1
+        else:
+            yield ""
 
 b = []
 for a in Get():
@@ -63,6 +78,7 @@ g = iter([1.0])
 #? float()
 next(g)
 
+
 # -----------------
 # __next__
 # -----------------
@@ -90,11 +106,12 @@ for c in Counter(3, 8):
     #? int()
     print c
 
+
 # -----------------
 # tuples
 # -----------------
 def gen():
-    if a:
+    if random.choice([0,1]):
         yield 1, ""
     else:
         yield 2, 1.0
@@ -105,3 +122,44 @@ a, b = next(gen())
 a
 #? str() float()
 b
+
+
+def simple():
+    if random.choice([0, 1]):
+        yield 1
+    else:
+        yield ""
+
+a, b = simple()
+#? int()
+a
+#? str()
+b
+
+
+# -----------------
+# More complicated access
+# -----------------
+
+# `close` is a method wrapper.
+#? ['__call__']
+gen().close.__call__
+
+#? 
+gen().throw()
+
+#? ['co_consts']
+gen().gi_code.co_consts
+
+#? []
+gen.gi_code.co_consts
+
+# `send` is also a method wrapper.
+#? ['__call__']
+gen().send.__call__
+
+#? tuple()
+gen().send()
+
+#? 
+gen()()
