@@ -1,11 +1,16 @@
-import readline
+try:
+    import readline
+except ImportError:
+    readline = False
 
 from jedi import utils
-from .helpers import TestCase, cwd_at
+
+from .helpers import unittest, cwd_at
 
 
-class TestSetupReadline(TestCase):
-    class NameSpace():
+@unittest.skipIf(not readline, "readline not found")
+class TestSetupReadline(unittest.TestCase):
+    class NameSpace(object):
         pass
 
     def __init__(self, *args, **kwargs):
@@ -46,14 +51,15 @@ class TestSetupReadline(TestCase):
         self.namespace.sys = sys
         self.namespace.os = os
 
-        assert self.completions('os.path.join') == ['os.path.join']
-        assert self.completions('os.path.join().upper') == ['os.path.join().upper']
+        try:
+            assert self.completions('os.path.join') == ['os.path.join']
+            assert self.completions('os.path.join().upper') == ['os.path.join().upper']
 
-        c = set(['os.' + d for d in dir(os) if d.startswith('ch')])
-        assert set(self.completions('os.ch')) == set(c)
-
-        del self.namespace.sys
-        del self.namespace.os
+            c = set(['os.' + d for d in dir(os) if d.startswith('ch')])
+            assert set(self.completions('os.ch')) == set(c)
+        finally:
+            del self.namespace.sys
+            del self.namespace.os
 
     def test_calls(self):
         s = 'str(bytes'
@@ -98,3 +104,7 @@ class TestSetupReadline(TestCase):
             assert self.completions('colorama')
             assert self.completions('colorama.Fore.BLACK') == ['colorama.Fore.BLACK']
             del self.namespace.colorama
+
+
+def test_version_info():
+    assert utils.version_info()[:2] > (0, 7)
